/*
@file    tft.c
@brief   TFT handling functions for EVE_Test project
@date    2023-04-11
@author  Rudolph Riedel
 */

#include "EVE.h"
#include "tft.h"

/* some pre-definded colors */
#define RED     0xff0000UL
#define ORANGE  0xffa500UL
#define GREEN   0x00ff00UL
#define BLUE    0x0000ffUL
#define BLUE_1  0x5dade2L
#define YELLOW  0xffff00UL
#define MAGENTA 0xff00ffUL
#define PURPLE  0x800080UL
#define WHITE   0xffffffUL
#define BLACK   0x000000UL

uint8_t tft_active = 0;
uint16_t num_profile_a = 0;
uint16_t num_profile_b = 0;

void TFT_init(void)
{
    if(E_OK == EVE_init())
    {
        tft_active = 1;

        EVE_memWrite8(REG_PWM_DUTY, 0x30);  /* setup backlight, range is from 0 = off to 0x80 = max */

        EVE_memWrite32(EVE_RAM_DL, DL_CLEAR_COLOR_RGB);
        EVE_memWrite32(EVE_RAM_DL + 4U, (DL_CLEAR | CLR_COL | CLR_STN | CLR_TAG));
        EVE_memWrite32(EVE_RAM_DL + 8U, VERTEX_FORMAT(0U));
        EVE_memWrite32(EVE_RAM_DL + 12U, DL_COLOR_RGB + 0xff00ff);
        EVE_memWrite32(EVE_RAM_DL + 16U, POINT_SIZE(300U));
        EVE_memWrite32(EVE_RAM_DL + 20U, DL_BEGIN + EVE_POINTS);
        EVE_memWrite32(EVE_RAM_DL + 24U, VERTEX2F(100, 100));
        EVE_memWrite32(EVE_RAM_DL + 28U, DL_DISPLAY); /* end of display list */
        EVE_memWrite32(REG_DLSWAP, EVE_DLSWAP_FRAME);

        DELAY_MS(20);

        EVE_memWrite32(EVE_RAM_DL, DL_CLEAR_COLOR_RGB);
        EVE_memWrite32(EVE_RAM_DL + 4U, (DL_CLEAR | CLR_COL | CLR_STN | CLR_TAG));
        EVE_memWrite32(EVE_RAM_DL + 8U, VERTEX_FORMAT(0U));
        EVE_memWrite32(EVE_RAM_DL + 12U, DL_COLOR_RGB + 0xff00ff);
        EVE_memWrite32(EVE_RAM_DL + 16U, POINT_SIZE(300U));
        EVE_memWrite32(EVE_RAM_DL + 20U, DL_BEGIN + EVE_POINTS);
        EVE_memWrite32(EVE_RAM_DL + 24U, VERTEX2F(100, 100));
        EVE_memWrite32(EVE_RAM_DL + 28U, DL_DISPLAY); /* end of display list */
        EVE_memWrite32(REG_DLSWAP, EVE_DLSWAP_FRAME);
    }
}

void TFT_touch(void)
{
}

void TFT_display(void)
{
    static int16_t xc = 100, yc = 100;

    if(tft_active != 0U)
    {
        EVE_memWrite32(EVE_RAM_DL + 24U, VERTEX2F(xc, yc));
        EVE_memWrite32(REG_DLSWAP, EVE_DLSWAP_FRAME);

        xc++;
        yc++;

        if(xc > 800)
        {
            xc = 0;
        }

        if(yc > 400)
        {
            yc = 0;
        }
    }
}
